@@ -75,6 +75,8 @@ public:
     QString currentBrowseCategory() const;
     void setStackHead( const DB::FileName& image );
     void setHistogramVisibilty( bool visible ) const;
+    void v6UpdateDone();
+    void v6UpdateSkipped();
 
 public slots:
     void showThumbNails(const DB::FileNameList& items);
@@ -158,7 +160,6 @@ protected slots:
     void useNextVideoThumbnail();
     void usePreviousVideoThumbnail();
     void mergeDuplicates();
-    void editBirthDates();
     void slotThumbnailSizeChanged();
 
 protected:
@@ -239,6 +240,9 @@ private:
     bool m_hasLoadedPlugins;
     QMap<Qt::Key, QPair<QString,QString> > m_viewerInputMacros;
     MainWindow::StatusBar* m_statusBar;
+
+    bool m_v6UpdateDone = false;
+    bool m_v6UpdateSkipped = false;
 };
 
 }
